{{
                  ===== QUICKSTART BOARD DEMO SOFTWARE =====
                      Copyright Ray Tracy June 2011
                      Mit License - blah blah blah

      Load this on your quickstart board then press sw8 + one of sw1,sw2,sw3,sw4 etc. (Sw8 is on the left)
      Each demo runs for a set time or number of cycles and then returns to monitoring the switches
}}
CON
  _CLKMODE = XTAL1 + PLL16X
  _CLKFREQ = 80_000_000
  
  Clock    = 80000000                ' Precalculated time delays in clocks
  Sec1     = Clock
  ms500    = Clock / 2
  ms100    = Clock / 10
  ms50     = Clock / 20
  ms10     = Clock / 100
  ms5      = Clock / 200
  ms1      = Clock / 1000

  Maxcogs      = 4
  LedsOn       = $00FF0000           ' Bit patterns for the leds and buttons
  LedsOff      = $FF00FFFF
  ButtonsOn    = $000000FF
  ButtonsOff   = $FFFFFF00
   
OBJ                                     ' External modules
  Buttons      : "Touch Buttons"        ' This is the original button interface
  Sequencer    : "LedSequencer_asm"     ' This is my Mother of all LED Sequencers
  Led[Maxcogs] : "Toggle"               ' Maxcogs instances of toggle demo from propeller manual


PUB Main
  Buttons.Start(ms1)
  repeat
    case GetButtons                  ' Check Buttons to see what to do
         $81: GoButtons              ' This is the original buttons demo
         $82: GoSequencer            ' This is my led sequencer
         $84: GoCount                ' This is a simple count to 255 
         $88: GoToggle               ' This is the toggle demo from the manual
         $90: GoPushPull             ' This is like Beau Schwabs Push on Push off demo
    waitcnt( ms1+cnt)

Pri GoButtons                             ' The original button demo
  dira |= LedsOn                          ' Set the LEDs as outputs
  repeat 50000                            ' 50000 loops (about 30 seconds)
    outa[23..16] := GetButtons            ' Light the LEDs when touching the corresponding buttons
  outa[23..16] := 0                       ' Turn off the lights when you leave

Pri GoSequencer                           ' Run my Led pattern generator
    waitcnt(ms1+cnt)
    Sequencer.Start                       ' Sequencer runs one complete cycle and shuts off

Pri GoCount | i                           ' Display a binary count (0-255) on the leds
   dira := LedsOn
   repeat i from 0 to 256
      outa[23..16] := i
      waitcnt(50*ms1+cnt)

Pri GoToggle                                     ' This is the LED Toggle demo from the Propeller Manual
   Dira := LedsOn
   Led[NextObject].Start(17, ms10*2,750)         ' Each line launches 1 cog to blink one led at
   Led[NextObject].Start(19, ms50,900)           '     a certain rate and duration
   Led[NextObject].Start(21, ms10+ms5,2000)      ' It waits for a cog if no cogs are available
   Led[NextObject].Start(23, ms100,150)
   Led[NextObject].Start(16, ms500,75)
   Led[NextObject].Start(18, ms10*2,750)
   Led[NextObject].Start(20, ms1*8,250)
   Led[NextObject].Start(22, ms10*75,50)
   Led[NextObject].Start(17, ms10,1500)
   Led[NextObject].Start(19, ms50,700)
   Led[NextObject].Start(21, ms10*3,900)

Pri NextObject : Index                    ' Wait for a free cog, then return its number
   repeat
      repeat Index from 0 to maxcogs-1    ' Loop thru the cogs
         if not LED[Index].Active         ' Ask the cog if it is busy
            quit                          '    return its number if it is not
   while Index == maxcogs                 ' Maxcogs controls how many cogs we use

Pri GoPushPull | S1,S2                    ' Duplicates Beau Schwabs push on push off demo (but not as reliable)
   dira := LedsOn                         ' Set LED pins to output
   S1 := 0                                ' Set initial button state
   repeat 6000                            ' About 60 seconds before terminateing
      S2 := GetButtons                    ' See what buttons changed state if any
      waitcnt(cnt+ms5)                    ' A small delay to be sure of a change
      if S2 == GetButtons                 ' Ok we have a change
         S1 ^=  S2                        ' Set the new output state
      outa[23..16] := S1                  ' Display it
   outa[23..16] := 0                      ' Turn off the lights when you leave
     
Pri GetButtons                            ' Get button state translated to spin
    return Buttons.State
' This is my code that duplicates "Touch Buttons" in spin
'    outa |= ButtonsOn                     ' Set all buttons high
'    dira |= ButtonsOn                     ' Now set Button pins to output (charges circuit)
'    dira &= ButtonsOff                    ' Set Button pins to input
'    waitcnt(ms1+cnt)                      ' Wait a bit (Allows discharge thru finger)
'    return ina[7..0] ^ $FF                ' Return inverted button state (ie one for each button pressed)
             